import * as React from 'react';
import type { BarChartProps } from "./BarChart.js";
import { ChartContainerProps } from "../ChartContainer/index.js";
import { BarPlotProps } from "./BarPlot.js";
import { ChartsGridProps } from "../ChartsGrid/index.js";
import { ChartsClipPathProps } from "../ChartsClipPath/index.js";
import { ChartsOverlayProps } from "../ChartsOverlay/index.js";
import { ChartsAxisProps } from "../ChartsAxis/index.js";
import { ChartsAxisHighlightProps } from "../ChartsAxisHighlight/index.js";
import { ChartsLegendSlotExtension } from "../ChartsLegend/index.js";
import type { ChartsWrapperProps } from "../internals/components/ChartsWrapper/index.js";
import { BarChartPluginsSignatures } from "./BarChart.plugins.js";
/**
 * A helper function that extracts BarChartProps from the input props
 * and returns an object with props for the children components of BarChart.
 *
 * @param props The input props for BarChart
 * @returns An object with props for the children components of BarChart
 */
export declare const useBarChartProps: (props: BarChartProps) => {
  chartsWrapperProps: Omit<ChartsWrapperProps, "children">;
  chartContainerProps: ChartContainerProps<"bar", BarChartPluginsSignatures>;
  barPlotProps: BarPlotProps;
  gridProps: ChartsGridProps;
  clipPathProps: ChartsClipPathProps;
  clipPathGroupProps: {
    clipPath: string;
  };
  overlayProps: ChartsOverlayProps;
  chartsAxisProps: ChartsAxisProps;
  axisHighlightProps: ChartsAxisHighlightProps;
  legendProps: ChartsLegendSlotExtension;
  children: React.ReactNode;
};