import { ScatterItemIdentifier } from "../../../../models/seriesType/index.js";
import { UseChartSeriesSignature } from "../../corePlugins/useChartSeries/index.js";
import { ChartPluginSignature } from "../../models/index.js";
import { UseChartCartesianAxisSignature } from "../useChartCartesianAxis/index.js";
import { UseChartHighlightSignature } from "../useChartHighlight/index.js";
import { UseChartInteractionSignature } from "../useChartInteraction/index.js";
export interface UseChartVoronoiInstance {
  /**
   * Enable the voronoi computation.
   */
  enableVoronoi: () => void;
  /**
   * Disable the voronoi computation.
   */
  disableVoronoi: () => void;
}
export interface UseChartVoronoiState {
  voronoi: {
    /**
     * Set to `true` when `VoronoiHandler` is active.
     * Used to prevent collision with mouseEnter events.
     */
    isVoronoiEnabled?: boolean;
  };
}
export interface UseChartVoronoiParameters {
  /**
   * If true, the voronoi interaction are ignored.
   */
  disableVoronoi?: boolean;
  /**
   * Defines the maximal distance between a scatter point and the pointer that triggers the interaction.
   * If `undefined`, the radius is assumed to be infinite.
   */
  voronoiMaxRadius?: number | undefined;
  /**
   * Callback fired when clicking close to an item.
   * This is only available for scatter plot for now.
   * @param {MouseEvent} event Mouse event caught at the svg level
   * @param {ScatterItemIdentifier} scatterItemIdentifier Identify which item got clicked
   */
  onItemClick?: (event: MouseEvent, scatterItemIdentifier: ScatterItemIdentifier) => void;
}
export type UseChartVoronoiDefaultizedParameters = UseChartVoronoiParameters & {
  disableVoronoi: boolean;
};
export type UseChartVoronoiSignature = ChartPluginSignature<{
  instance: UseChartVoronoiInstance;
  state: UseChartVoronoiState;
  params: UseChartVoronoiParameters;
  defaultizedParams: UseChartVoronoiDefaultizedParameters;
  dependencies: [UseChartSeriesSignature, UseChartCartesianAxisSignature];
  optionalDependencies: [UseChartInteractionSignature, UseChartHighlightSignature];
}>;